This package provides accurate and computationally efficient methods for computing p-values for a general family of Fisher-type statistics (GFisher), including Fisher's combination, Good's statistic, and Lancaster's statistic.

Weight Normalization Convention

All functions in this package normalize weights so that \(\sum w_i = 1\). This normalization:

  • Improves numerical stability in p-value calculations

  • Is statistically equivalent to other normalizations (e.g., \(\sum w_i = n\)) in terms of its p-value results

  • Focuses on hypothesis testing rather than arbitrary distributions

When you provide weights, they are automatically rescaled internally. For example, w = c(1, 2, 3) is equivalent to w = c(1/6, 2/6, 3/6).

References

Zhang, H. and Wu, Z. (2022). The generalized Fisher's combination and accurate p-value calculation under dependence. Biometrics, 79(2), 1159-1172. doi:10.1111/biom.13634

See also

Author

Zheyang Wu zheyangwu@wpi.edu

Hong Zhang consistencyzhang@gmail.com