R/RcppExports.R
clear_GFisher_cache.Rd
Clears the internal cache used by getGFishercoef_cached_cpp. This can be useful to free memory or force recomputation.
clear_GFisher_cache()
The number of entries that were cleared from the cache.